@@ -22,5 +22,6 @@ echo -e "\e[1;36m1. Navigate to https://$HOST_IP:30300/dashboard on your browser
 echo -e "\e[1;36m\n2. Navigate to https://$HOST_IP:32000 on your browser to login to the Grafana dashboard.\e[0m"
 echo -e "\e[1;32m\nLogin with the below mentioned credentials"
 echo -e "\e[1;33mUsername : admin\e[0m"
-GRAFANA_PWD=$(kubectl get secrets/grafana -n telemetry -o json | jq -r '.data."admin-password"' | base64 -d)
-echo -e "\e[1;33mGrafana Password : $GRAFANA_PWD\e[0m"
+echo -e "\e[1;33mGrafana Password : \e[0m"
+kubectl get secrets/grafana -n telemetry -o json | jq -r '.data."admin-password"' | base64 -d
+
